MoonColors class

Constructors

MoonColors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

background → const Color
border → const Color
error → const Color
info → const Color
muted → const Color
primary → const Color
secondary → const Color
success → const Color
surface → const Color
text → const Color
warning → const Color