MoonIcons class

Constructors

MoonIcons()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

arrowLeft → const IconData
arrowRight → const IconData
check → const IconData
close → const IconData
error → const IconData
info → const IconData
star → const IconData
user → const IconData
warning → const IconData